# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vplexapi.api_client import ApiClient


class DataMigrationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_device_migration(self, device_migration_payload, **kwargs):  # noqa: E501
        """Create a new DeviceMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_device_migration(device_migration_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DeviceMigrationPayload device_migration_payload: (required)
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_device_migration_with_http_info(device_migration_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_device_migration_with_http_info(device_migration_payload, **kwargs)  # noqa: E501
            return data

    def create_device_migration_with_http_info(self, device_migration_payload, **kwargs):  # noqa: E501
        """Create a new DeviceMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_device_migration_with_http_info(device_migration_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param DeviceMigrationPayload device_migration_payload: (required)
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_migration_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_device_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_migration_payload' is set
        if ('device_migration_payload' not in params or
                params['device_migration_payload'] is None):
            raise ValueError("Missing the required parameter `device_migration_payload` when calling `create_device_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'device_migration_payload' in params:
            body_params = params['device_migration_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/device_migrations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_extent_migration(self, extent_migration_payload, **kwargs):  # noqa: E501
        """Create a new ExtentMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_extent_migration(extent_migration_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param ExtentMigrationPayload extent_migration_payload: (required)
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_extent_migration_with_http_info(extent_migration_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_extent_migration_with_http_info(extent_migration_payload, **kwargs)  # noqa: E501
            return data

    def create_extent_migration_with_http_info(self, extent_migration_payload, **kwargs):  # noqa: E501
        """Create a new ExtentMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_extent_migration_with_http_info(extent_migration_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param ExtentMigrationPayload extent_migration_payload: (required)
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['extent_migration_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_extent_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'extent_migration_payload' is set
        if ('extent_migration_payload' not in params or
                params['extent_migration_payload'] is None):
            raise ValueError("Missing the required parameter `extent_migration_payload` when calling `create_extent_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'extent_migration_payload' in params:
            body_params = params['extent_migration_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/extent_migrations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExtentMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_device_migration(self, name, **kwargs):  # noqa: E501
        """Deletes a single canceled or committed DeviceMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_device_migration(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_device_migration_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_device_migration_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_device_migration_with_http_info(self, name, **kwargs):  # noqa: E501
        """Deletes a single canceled or committed DeviceMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_device_migration_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_device_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_device_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/device_migrations/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_extent_migration(self, name, **kwargs):  # noqa: E501
        """Deletes a single canceled or committed ExtentMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_extent_migration(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_extent_migration_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_extent_migration_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def delete_extent_migration_with_http_info(self, name, **kwargs):  # noqa: E501
        """Deletes a single canceled or committed ExtentMigration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_extent_migration_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_extent_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_extent_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/extent_migrations/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_migration(self, name, **kwargs):  # noqa: E501
        """Returns a single DeviceMigration object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_device_migration(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_device_migration_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_device_migration_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_device_migration_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single DeviceMigration object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_device_migration_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_device_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/device_migrations/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_migrations(self, **kwargs):  # noqa: E501
        """Returns a list of device migrations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_device_migrations(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str to_cluster: Filter results by to_cluster. See LexicalQueryExpression for details.
        :param str from_cluster: Filter results by from_cluster. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[DeviceMigration]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_device_migrations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_device_migrations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_device_migrations_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of device migrations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_device_migrations_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str to_cluster: Filter results by to_cluster. See LexicalQueryExpression for details.
        :param str from_cluster: Filter results by from_cluster. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[DeviceMigration]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'to_cluster', 'from_cluster', 'offset', 'limit', 'sort_by', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_migrations" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_device_migrations`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_device_migrations`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_device_migrations`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'to_cluster' in params:
            query_params.append(('to_cluster', params['to_cluster']))  # noqa: E501
        if 'from_cluster' in params:
            query_params.append(('from_cluster', params['from_cluster']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sort_by', params['sort_by']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/device_migrations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DeviceMigration]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_extent_migration(self, name, **kwargs):  # noqa: E501
        """Returns a single ExtentMigration object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_extent_migration(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_extent_migration_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_extent_migration_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_extent_migration_with_http_info(self, name, **kwargs):  # noqa: E501
        """Returns a single ExtentMigration object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_extent_migration_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_extent_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_extent_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/extent_migrations/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExtentMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_extent_migrations(self, **kwargs):  # noqa: E501
        """Returns a list of extent migrations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_extent_migrations(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str to_cluster: Filter results by to_cluster. See LexicalQueryExpression for details.
        :param str from_cluster: Filter results by from_cluster. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[ExtentMigration]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_extent_migrations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_extent_migrations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_extent_migrations_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a list of extent migrations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_extent_migrations_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Filter results by name. See LexicalQueryExpression for details.
        :param str to_cluster: Filter results by to_cluster. See LexicalQueryExpression for details.
        :param str from_cluster: Filter results by from_cluster. See LexicalQueryExpression for details.
        :param int offset: Index of the first element to include in paginated results.<br> <b>'limit' must also be specified.</b>
        :param int limit: <p>Maximum number of elements to include in paginated results.<br> <b>'offset' must also be specified.<b>
        :param str sort_by: Specify the field priority order and direction for sorting.  See SortingOrderExpression for details. 
        :param str fields: Select which fields are included in the response. 'name' is always included. See FieldSelectionExpression for details. 
        :return: list[ExtentMigration]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'to_cluster', 'from_cluster', 'offset', 'limit', 'sort_by', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_extent_migrations" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_extent_migrations`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in params and params['limit'] > 100:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_extent_migrations`, must be a value less than or equal to `100`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_extent_migrations`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'to_cluster' in params:
            query_params.append(('to_cluster', params['to_cluster']))  # noqa: E501
        if 'from_cluster' in params:
            query_params.append(('from_cluster', params['from_cluster']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sort_by', params['sort_by']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/extent_migrations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ExtentMigration]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_device_migration(self, name, device_migration_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a DeviceMigration  # noqa: E501

        Settable attributes: 'name', 'transfer_size' and 'status'(replace)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_device_migration(name, device_migration_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] device_migration_patch_payload: (required)
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.patch_device_migration_with_http_info(name, device_migration_patch_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_device_migration_with_http_info(name, device_migration_patch_payload, **kwargs)  # noqa: E501
            return data

    def patch_device_migration_with_http_info(self, name, device_migration_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a DeviceMigration  # noqa: E501

        Settable attributes: 'name', 'transfer_size' and 'status'(replace)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_device_migration_with_http_info(name, device_migration_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] device_migration_patch_payload: (required)
        :return: DeviceMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'device_migration_patch_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_device_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `patch_device_migration`")  # noqa: E501
        # verify the required parameter 'device_migration_patch_payload' is set
        if ('device_migration_patch_payload' not in params or
                params['device_migration_patch_payload'] is None):
            raise ValueError("Missing the required parameter `device_migration_patch_payload` when calling `patch_device_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'device_migration_patch_payload' in params:
            body_params = params['device_migration_patch_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/device_migrations/{name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeviceMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_extent_migration(self, name, extent_migration_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a ExtentMigration  # noqa: E501

        Settable attributes: 'name', 'transfer_size' and 'status'(replace)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_extent_migration(name, extent_migration_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] extent_migration_patch_payload: (required)
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.patch_extent_migration_with_http_info(name, extent_migration_patch_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_extent_migration_with_http_info(name, extent_migration_patch_payload, **kwargs)  # noqa: E501
            return data

    def patch_extent_migration_with_http_info(self, name, extent_migration_patch_payload, **kwargs):  # noqa: E501
        """Update attributes on a ExtentMigration  # noqa: E501

        Settable attributes: 'name', 'transfer_size' and 'status'(replace)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.patch_extent_migration_with_http_info(name, extent_migration_patch_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: The name of a specific instance of the resource (required)
        :param list[JsonPatchOp] extent_migration_patch_payload: (required)
        :return: ExtentMigration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'extent_migration_patch_payload']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_extent_migration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `patch_extent_migration`")  # noqa: E501
        # verify the required parameter 'extent_migration_patch_payload' is set
        if ('extent_migration_patch_payload' not in params or
                params['extent_migration_patch_payload'] is None):
            raise ValueError("Missing the required parameter `extent_migration_patch_payload` when calling `patch_extent_migration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'extent_migration_patch_payload' in params:
            body_params = params['extent_migration_patch_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/data_migrations/extent_migrations/{name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ExtentMigration',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.connectivity_status import ConnectivityStatus  # noqa: F401,E501
from vplexapi.models.storage_array_family import StorageArrayFamily  # noqa: F401,E501


class StorageArray(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'controllers': 'list[str]',
        'auto_switch': 'bool',
        'connectivity_status': 'ConnectivityStatus',
        'ports': 'list[str]',
        'logical_unit_count': 'int',
        'product_revision': 'str',
        'storage_array_family': 'StorageArrayFamily',
        'storage_pools': 'str',
        'storage_groups': 'str'
    }

    attribute_map = {
        'name': 'name',
        'controllers': 'controllers',
        'auto_switch': 'auto_switch',
        'connectivity_status': 'connectivity_status',
        'ports': 'ports',
        'logical_unit_count': 'logical_unit_count',
        'product_revision': 'product_revision',
        'storage_array_family': 'storage_array_family',
        'storage_pools': 'storage_pools',
        'storage_groups': 'storage_groups'
    }

    def __init__(self, name=None, controllers=None, auto_switch=None, connectivity_status=None, ports=None, logical_unit_count=None, product_revision=None, storage_array_family=None, storage_pools=None, storage_groups=None):  # noqa: E501
        """StorageArray - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._controllers = None
        self._auto_switch = None
        self._connectivity_status = None
        self._ports = None
        self._logical_unit_count = None
        self._product_revision = None
        self._storage_array_family = None
        self._storage_pools = None
        self._storage_groups = None
        self.discriminator = None

        self.name = name
        if controllers is not None:
            self.controllers = controllers
        if auto_switch is not None:
            self.auto_switch = auto_switch
        if connectivity_status is not None:
            self.connectivity_status = connectivity_status
        if ports is not None:
            self.ports = ports
        if logical_unit_count is not None:
            self.logical_unit_count = logical_unit_count
        if product_revision is not None:
            self.product_revision = product_revision
        if storage_array_family is not None:
            self.storage_array_family = storage_array_family
        if storage_pools is not None:
            self.storage_pools = storage_pools
        if storage_groups is not None:
            self.storage_groups = storage_groups

    @property
    def name(self):
        """Gets the name of this StorageArray.  # noqa: E501


        :return: The name of this StorageArray.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageArray.


        :param name: The name of this StorageArray.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def controllers(self):
        """Gets the controllers of this StorageArray.  # noqa: E501


        :return: The controllers of this StorageArray.  # noqa: E501
        :rtype: list[str]
        """
        return self._controllers

    @controllers.setter
    def controllers(self, controllers):
        """Sets the controllers of this StorageArray.


        :param controllers: The controllers of this StorageArray.  # noqa: E501
        :type: list[str]
        """

        self._controllers = controllers

    @property
    def auto_switch(self):
        """Gets the auto_switch of this StorageArray.  # noqa: E501


        :return: The auto_switch of this StorageArray.  # noqa: E501
        :rtype: bool
        """
        return self._auto_switch

    @auto_switch.setter
    def auto_switch(self, auto_switch):
        """Sets the auto_switch of this StorageArray.


        :param auto_switch: The auto_switch of this StorageArray.  # noqa: E501
        :type: bool
        """

        self._auto_switch = auto_switch

    @property
    def connectivity_status(self):
        """Gets the connectivity_status of this StorageArray.  # noqa: E501


        :return: The connectivity_status of this StorageArray.  # noqa: E501
        :rtype: ConnectivityStatus
        """
        return self._connectivity_status

    @connectivity_status.setter
    def connectivity_status(self, connectivity_status):
        """Sets the connectivity_status of this StorageArray.


        :param connectivity_status: The connectivity_status of this StorageArray.  # noqa: E501
        :type: ConnectivityStatus
        """

        self._connectivity_status = connectivity_status

    @property
    def ports(self):
        """Gets the ports of this StorageArray.  # noqa: E501


        :return: The ports of this StorageArray.  # noqa: E501
        :rtype: list[str]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this StorageArray.


        :param ports: The ports of this StorageArray.  # noqa: E501
        :type: list[str]
        """

        self._ports = ports

    @property
    def logical_unit_count(self):
        """Gets the logical_unit_count of this StorageArray.  # noqa: E501


        :return: The logical_unit_count of this StorageArray.  # noqa: E501
        :rtype: int
        """
        return self._logical_unit_count

    @logical_unit_count.setter
    def logical_unit_count(self, logical_unit_count):
        """Sets the logical_unit_count of this StorageArray.


        :param logical_unit_count: The logical_unit_count of this StorageArray.  # noqa: E501
        :type: int
        """

        self._logical_unit_count = logical_unit_count

    @property
    def product_revision(self):
        """Gets the product_revision of this StorageArray.  # noqa: E501


        :return: The product_revision of this StorageArray.  # noqa: E501
        :rtype: str
        """
        return self._product_revision

    @product_revision.setter
    def product_revision(self, product_revision):
        """Sets the product_revision of this StorageArray.


        :param product_revision: The product_revision of this StorageArray.  # noqa: E501
        :type: str
        """

        self._product_revision = product_revision

    @property
    def storage_array_family(self):
        """Gets the storage_array_family of this StorageArray.  # noqa: E501


        :return: The storage_array_family of this StorageArray.  # noqa: E501
        :rtype: StorageArrayFamily
        """
        return self._storage_array_family

    @storage_array_family.setter
    def storage_array_family(self, storage_array_family):
        """Sets the storage_array_family of this StorageArray.


        :param storage_array_family: The storage_array_family of this StorageArray.  # noqa: E501
        :type: StorageArrayFamily
        """

        self._storage_array_family = storage_array_family

    @property
    def storage_pools(self):
        """Gets the storage_pools of this StorageArray.  # noqa: E501


        :return: The storage_pools of this StorageArray.  # noqa: E501
        :rtype: str
        """
        return self._storage_pools

    @storage_pools.setter
    def storage_pools(self, storage_pools):
        """Sets the storage_pools of this StorageArray.


        :param storage_pools: The storage_pools of this StorageArray.  # noqa: E501
        :type: str
        """

        self._storage_pools = storage_pools

    @property
    def storage_groups(self):
        """Gets the storage_groups of this StorageArray.  # noqa: E501


        :return: The storage_groups of this StorageArray.  # noqa: E501
        :rtype: str
        """
        return self._storage_groups

    @storage_groups.setter
    def storage_groups(self, storage_groups):
        """Sets the storage_groups of this StorageArray.


        :param storage_groups: The storage_groups of this StorageArray.  # noqa: E501
        :type: str
        """

        self._storage_groups = storage_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageArray):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.storage_array_family import StorageArrayFamily  # noqa: F401,E501


class MetaVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'application_consistent': 'bool',
        'block_count': 'int',
        'block_size': 'int',
        'capacity': 'int',
        'health_indications': 'list[str]',
        'health_state': 'str',
        'name': 'str',
        'operational_status': 'str',
        'storage_array_family': 'StorageArrayFamily',
        'system_id': 'str'
    }

    attribute_map = {
        'active': 'active',
        'application_consistent': 'application_consistent',
        'block_count': 'block_count',
        'block_size': 'block_size',
        'capacity': 'capacity',
        'health_indications': 'health_indications',
        'health_state': 'health_state',
        'name': 'name',
        'operational_status': 'operational_status',
        'storage_array_family': 'storage_array_family',
        'system_id': 'system_id'
    }

    def __init__(self, active=None, application_consistent=None, block_count=None, block_size=None, capacity=None, health_indications=None, health_state=None, name=None, operational_status=None, storage_array_family=None, system_id=None):  # noqa: E501
        """MetaVolume - a model defined in Swagger"""  # noqa: E501

        self._active = None
        self._application_consistent = None
        self._block_count = None
        self._block_size = None
        self._capacity = None
        self._health_indications = None
        self._health_state = None
        self._name = None
        self._operational_status = None
        self._storage_array_family = None
        self._system_id = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if application_consistent is not None:
            self.application_consistent = application_consistent
        if block_count is not None:
            self.block_count = block_count
        if block_size is not None:
            self.block_size = block_size
        if capacity is not None:
            self.capacity = capacity
        if health_indications is not None:
            self.health_indications = health_indications
        if health_state is not None:
            self.health_state = health_state
        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if storage_array_family is not None:
            self.storage_array_family = storage_array_family
        if system_id is not None:
            self.system_id = system_id

    @property
    def active(self):
        """Gets the active of this MetaVolume.  # noqa: E501


        :return: The active of this MetaVolume.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this MetaVolume.


        :param active: The active of this MetaVolume.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def application_consistent(self):
        """Gets the application_consistent of this MetaVolume.  # noqa: E501


        :return: The application_consistent of this MetaVolume.  # noqa: E501
        :rtype: bool
        """
        return self._application_consistent

    @application_consistent.setter
    def application_consistent(self, application_consistent):
        """Sets the application_consistent of this MetaVolume.


        :param application_consistent: The application_consistent of this MetaVolume.  # noqa: E501
        :type: bool
        """

        self._application_consistent = application_consistent

    @property
    def block_count(self):
        """Gets the block_count of this MetaVolume.  # noqa: E501


        :return: The block_count of this MetaVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_count

    @block_count.setter
    def block_count(self, block_count):
        """Sets the block_count of this MetaVolume.


        :param block_count: The block_count of this MetaVolume.  # noqa: E501
        :type: int
        """

        self._block_count = block_count

    @property
    def block_size(self):
        """Gets the block_size of this MetaVolume.  # noqa: E501


        :return: The block_size of this MetaVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_size

    @block_size.setter
    def block_size(self, block_size):
        """Sets the block_size of this MetaVolume.


        :param block_size: The block_size of this MetaVolume.  # noqa: E501
        :type: int
        """

        self._block_size = block_size

    @property
    def capacity(self):
        """Gets the capacity of this MetaVolume.  # noqa: E501


        :return: The capacity of this MetaVolume.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this MetaVolume.


        :param capacity: The capacity of this MetaVolume.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def health_indications(self):
        """Gets the health_indications of this MetaVolume.  # noqa: E501


        :return: The health_indications of this MetaVolume.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this MetaVolume.


        :param health_indications: The health_indications of this MetaVolume.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def health_state(self):
        """Gets the health_state of this MetaVolume.  # noqa: E501


        :return: The health_state of this MetaVolume.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this MetaVolume.


        :param health_state: The health_state of this MetaVolume.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def name(self):
        """Gets the name of this MetaVolume.  # noqa: E501


        :return: The name of this MetaVolume.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MetaVolume.


        :param name: The name of this MetaVolume.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this MetaVolume.  # noqa: E501


        :return: The operational_status of this MetaVolume.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this MetaVolume.


        :param operational_status: The operational_status of this MetaVolume.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def storage_array_family(self):
        """Gets the storage_array_family of this MetaVolume.  # noqa: E501


        :return: The storage_array_family of this MetaVolume.  # noqa: E501
        :rtype: StorageArrayFamily
        """
        return self._storage_array_family

    @storage_array_family.setter
    def storage_array_family(self, storage_array_family):
        """Sets the storage_array_family of this MetaVolume.


        :param storage_array_family: The storage_array_family of this MetaVolume.  # noqa: E501
        :type: StorageArrayFamily
        """

        self._storage_array_family = storage_array_family

    @property
    def system_id(self):
        """Gets the system_id of this MetaVolume.  # noqa: E501


        :return: The system_id of this MetaVolume.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this MetaVolume.


        :param system_id: The system_id of this MetaVolume.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetaVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InitiatorPort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'iscsi_name': 'str',
        'port_wwn': 'str',
        'node_wwn': 'str',
        'type': 'str',
        'iops_limit': 'int',
        'bandwidth_limit': 'str',
        'target_ports': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'iscsi_name': 'iscsi_name',
        'port_wwn': 'port_wwn',
        'node_wwn': 'node_wwn',
        'type': 'type',
        'iops_limit': 'iops_limit',
        'bandwidth_limit': 'bandwidth_limit',
        'target_ports': 'target_ports'
    }

    def __init__(self, name=None, iscsi_name=None, port_wwn=None, node_wwn=None, type=None, iops_limit=None, bandwidth_limit=None, target_ports=None):  # noqa: E501
        """InitiatorPort - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._iscsi_name = None
        self._port_wwn = None
        self._node_wwn = None
        self._type = None
        self._iops_limit = None
        self._bandwidth_limit = None
        self._target_ports = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if iscsi_name is not None:
            self.iscsi_name = iscsi_name
        if port_wwn is not None:
            self.port_wwn = port_wwn
        if node_wwn is not None:
            self.node_wwn = node_wwn
        if type is not None:
            self.type = type
        if iops_limit is not None:
            self.iops_limit = iops_limit
        if bandwidth_limit is not None:
            self.bandwidth_limit = bandwidth_limit
        if target_ports is not None:
            self.target_ports = target_ports

    @property
    def name(self):
        """Gets the name of this InitiatorPort.  # noqa: E501


        :return: The name of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InitiatorPort.


        :param name: The name of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def iscsi_name(self):
        """Gets the iscsi_name of this InitiatorPort.  # noqa: E501


        :return: The iscsi_name of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_name

    @iscsi_name.setter
    def iscsi_name(self, iscsi_name):
        """Sets the iscsi_name of this InitiatorPort.


        :param iscsi_name: The iscsi_name of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._iscsi_name = iscsi_name

    @property
    def port_wwn(self):
        """Gets the port_wwn of this InitiatorPort.  # noqa: E501


        :return: The port_wwn of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._port_wwn

    @port_wwn.setter
    def port_wwn(self, port_wwn):
        """Sets the port_wwn of this InitiatorPort.


        :param port_wwn: The port_wwn of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._port_wwn = port_wwn

    @property
    def node_wwn(self):
        """Gets the node_wwn of this InitiatorPort.  # noqa: E501


        :return: The node_wwn of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._node_wwn

    @node_wwn.setter
    def node_wwn(self, node_wwn):
        """Sets the node_wwn of this InitiatorPort.


        :param node_wwn: The node_wwn of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._node_wwn = node_wwn

    @property
    def type(self):
        """Gets the type of this InitiatorPort.  # noqa: E501


        :return: The type of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InitiatorPort.


        :param type: The type of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def iops_limit(self):
        """Gets the iops_limit of this InitiatorPort.  # noqa: E501


        :return: The iops_limit of this InitiatorPort.  # noqa: E501
        :rtype: int
        """
        return self._iops_limit

    @iops_limit.setter
    def iops_limit(self, iops_limit):
        """Sets the iops_limit of this InitiatorPort.


        :param iops_limit: The iops_limit of this InitiatorPort.  # noqa: E501
        :type: int
        """

        self._iops_limit = iops_limit

    @property
    def bandwidth_limit(self):
        """Gets the bandwidth_limit of this InitiatorPort.  # noqa: E501


        :return: The bandwidth_limit of this InitiatorPort.  # noqa: E501
        :rtype: str
        """
        return self._bandwidth_limit

    @bandwidth_limit.setter
    def bandwidth_limit(self, bandwidth_limit):
        """Sets the bandwidth_limit of this InitiatorPort.


        :param bandwidth_limit: The bandwidth_limit of this InitiatorPort.  # noqa: E501
        :type: str
        """

        self._bandwidth_limit = bandwidth_limit

    @property
    def target_ports(self):
        """Gets the target_ports of this InitiatorPort.  # noqa: E501


        :return: The target_ports of this InitiatorPort.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_ports

    @target_ports.setter
    def target_ports(self, target_ports):
        """Sets the target_ports of this InitiatorPort.


        :param target_ports: The target_ports of this InitiatorPort.  # noqa: E501
        :type: list[str]
        """

        self._target_ports = target_ports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InitiatorPort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from vplexapi.models.admin_state import AdminState
from vplexapi.models.aggregate import Aggregate
from vplexapi.models.aggregates import Aggregates
from vplexapi.models.amp_payload import AmpPayload
from vplexapi.models.array_management_provider import ArrayManagementProvider
from vplexapi.models.bulk_response import BulkResponse
from vplexapi.models.bulk_response_tasks import BulkResponseTasks
from vplexapi.models.certificate import Certificate
from vplexapi.models.certificate_payload import CertificatePayload
from vplexapi.models.cg_resume_payload import CgResumePayload
from vplexapi.models.claim_payload import ClaimPayload
from vplexapi.models.cluster import Cluster
from vplexapi.models.cluster_witness import ClusterWitness
from vplexapi.models.cluster_witness_components import ClusterWitnessComponents
from vplexapi.models.com_status import ComStatus
from vplexapi.models.communication_status import CommunicationStatus
from vplexapi.models.connectivity_status import ConnectivityStatus
from vplexapi.models.consistency_group import ConsistencyGroup
from vplexapi.models.consistency_group_operational_status import ConsistencyGroupOperationalStatus
from vplexapi.models.consistency_group_payload import ConsistencyGroupPayload
from vplexapi.models.device import Device
from vplexapi.models.device_migration import DeviceMigration
from vplexapi.models.device_migration_payload import DeviceMigrationPayload
from vplexapi.models.device_payload import DevicePayload
from vplexapi.models.director import Director
from vplexapi.models.distributed_consistency_group_payload import DistributedConsistencyGroupPayload
from vplexapi.models.distributed_device import DistributedDevice
from vplexapi.models.distributed_device_payload import DistributedDevicePayload
from vplexapi.models.distributed_virtual_volume_expand_payload import DistributedVirtualVolumeExpandPayload
from vplexapi.models.distributed_virtual_volume_payload import DistributedVirtualVolumePayload
from vplexapi.models.engine import Engine
from vplexapi.models.error import Error
from vplexapi.models.extent import Extent
from vplexapi.models.extent_migration import ExtentMigration
from vplexapi.models.extent_migration_payload import ExtentMigrationPayload
from vplexapi.models.extent_payload import ExtentPayload
from vplexapi.models.field_selection_expression import FieldSelectionExpression
from vplexapi.models.hardware_port import HardwarePort
from vplexapi.models.hardware_ports import HardwarePorts
from vplexapi.models.health_state import HealthState
from vplexapi.models.initiator_port import InitiatorPort
from vplexapi.models.inline_response200 import InlineResponse200
from vplexapi.models.inline_response200_claimable_storage_volumes import InlineResponse200ClaimableStorageVolumes
from vplexapi.models.jobs_storage_pools import JobsStoragePools
from vplexapi.models.json_patch_op import JsonPatchOp
from vplexapi.models.lexical_query_expression import LexicalQueryExpression
from vplexapi.models.license import License
from vplexapi.models.license_array import LicenseArray
from vplexapi.models.license_payload import LicensePayload
from vplexapi.models.local_com_health import LocalComHealth
from vplexapi.models.logging_volume import LoggingVolume
from vplexapi.models.logical_unit import LogicalUnit
from vplexapi.models.login_payload import LoginPayload
from vplexapi.models.login_response import LoginResponse
from vplexapi.models.meta_volume import MetaVolume
from vplexapi.models.monitors import Monitors
from vplexapi.models.numeric_query_expression import NumericQueryExpression
from vplexapi.models.operational_status import OperationalStatus
from vplexapi.models.permission import Permission
from vplexapi.models.port import Port
from vplexapi.models.port_exports import PortExports
from vplexapi.models.rpa_cluster import RPACluster
from vplexapi.models.rediscover_payload import RediscoverPayload
from vplexapi.models.register_payload import RegisterPayload
from vplexapi.models.rule_set import RuleSet
from vplexapi.models.sorting_order_expression import SortingOrderExpression
from vplexapi.models.storage_array import StorageArray
from vplexapi.models.storage_array_family import StorageArrayFamily
from vplexapi.models.storage_group import StorageGroup
from vplexapi.models.storage_map import StorageMap
from vplexapi.models.storage_pool import StoragePool
from vplexapi.models.storage_view import StorageView
from vplexapi.models.storage_view_payload import StorageViewPayload
from vplexapi.models.storage_view_virtual_volumes import StorageViewVirtualVolumes
from vplexapi.models.storage_volume import StorageVolume
from vplexapi.models.storage_volume_itls import StorageVolumeItls
from vplexapi.models.system_config import SystemConfig
from vplexapi.models.uri import URI
from vplexapi.models.unclaim_payload import UnclaimPayload
from vplexapi.models.validate_payload import ValidatePayload
from vplexapi.models.version import Version
from vplexapi.models.versions import Versions
from vplexapi.models.vias_job import ViasJob
from vplexapi.models.vias_job_storage_pools import ViasJobStoragePools
from vplexapi.models.vias_payload import ViasPayload
from vplexapi.models.virtual_volume import VirtualVolume
from vplexapi.models.virtual_volume_expand_payload import VirtualVolumeExpandPayload
from vplexapi.models.virtual_volume_payload import VirtualVolumePayload
from vplexapi.models.wan_com_health import WanComHealth



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SystemAlert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_data': 'str',
        'component': 'str',
        'condition_id': 'str',
        'corrective_action': 'str',
        'created': 'datetime',
        'description': 'str',
        'enabled': 'bool',
        'event_source': 'str',
        'event_source_id': 'str',
        'external_rca': 'str',
        'id': 'int',
        'last_modified': 'datetime',
        'message': 'str',
        'name': 'str',
        'resource': 'str',
        'scope': 'str',
        'severity': 'str',
        'state': 'str'
    }

    attribute_map = {
        'additional_data': 'additionalData',
        'component': 'component',
        'condition_id': 'conditionId',
        'corrective_action': 'correctiveAction',
        'created': 'created',
        'description': 'description',
        'enabled': 'enabled',
        'event_source': 'eventSource',
        'event_source_id': 'eventSourceId',
        'external_rca': 'externalRCA',
        'id': 'id',
        'last_modified': 'lastModified',
        'message': 'message',
        'name': 'name',
        'resource': 'resource',
        'scope': 'scope',
        'severity': 'severity',
        'state': 'state'
    }

    def __init__(self, additional_data=None, component=None, condition_id=None, corrective_action=None, created=None, description=None, enabled=None, event_source=None, event_source_id=None, external_rca=None, id=None, last_modified=None, message=None, name=None, resource=None, scope=None, severity=None, state=None):  # noqa: E501
        """SystemAlert - a model defined in Swagger"""  # noqa: E501

        self._additional_data = None
        self._component = None
        self._condition_id = None
        self._corrective_action = None
        self._created = None
        self._description = None
        self._enabled = None
        self._event_source = None
        self._event_source_id = None
        self._external_rca = None
        self._id = None
        self._last_modified = None
        self._message = None
        self._name = None
        self._resource = None
        self._scope = None
        self._severity = None
        self._state = None
        self.discriminator = None

        if additional_data is not None:
            self.additional_data = additional_data
        if component is not None:
            self.component = component
        if condition_id is not None:
            self.condition_id = condition_id
        if corrective_action is not None:
            self.corrective_action = corrective_action
        if created is not None:
            self.created = created
        if description is not None:
            self.description = description
        if enabled is not None:
            self.enabled = enabled
        if event_source is not None:
            self.event_source = event_source
        if event_source_id is not None:
            self.event_source_id = event_source_id
        if external_rca is not None:
            self.external_rca = external_rca
        if id is not None:
            self.id = id
        if last_modified is not None:
            self.last_modified = last_modified
        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if resource is not None:
            self.resource = resource
        if scope is not None:
            self.scope = scope
        if severity is not None:
            self.severity = severity
        if state is not None:
            self.state = state

    @property
    def additional_data(self):
        """Gets the additional_data of this SystemAlert.  # noqa: E501


        :return: The additional_data of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._additional_data

    @additional_data.setter
    def additional_data(self, additional_data):
        """Sets the additional_data of this SystemAlert.


        :param additional_data: The additional_data of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._additional_data = additional_data

    @property
    def component(self):
        """Gets the component of this SystemAlert.  # noqa: E501


        :return: The component of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this SystemAlert.


        :param component: The component of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._component = component

    @property
    def condition_id(self):
        """Gets the condition_id of this SystemAlert.  # noqa: E501


        :return: The condition_id of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """Sets the condition_id of this SystemAlert.


        :param condition_id: The condition_id of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._condition_id = condition_id

    @property
    def corrective_action(self):
        """Gets the corrective_action of this SystemAlert.  # noqa: E501


        :return: The corrective_action of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._corrective_action

    @corrective_action.setter
    def corrective_action(self, corrective_action):
        """Sets the corrective_action of this SystemAlert.


        :param corrective_action: The corrective_action of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._corrective_action = corrective_action

    @property
    def created(self):
        """Gets the created of this SystemAlert.  # noqa: E501

        Creation date of Sytem Alert  # noqa: E501

        :return: The created of this SystemAlert.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SystemAlert.

        Creation date of Sytem Alert  # noqa: E501

        :param created: The created of this SystemAlert.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def description(self):
        """Gets the description of this SystemAlert.  # noqa: E501

        Description of Sytem Alert  # noqa: E501

        :return: The description of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SystemAlert.

        Description of Sytem Alert  # noqa: E501

        :param description: The description of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """Gets the enabled of this SystemAlert.  # noqa: E501


        :return: The enabled of this SystemAlert.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this SystemAlert.


        :param enabled: The enabled of this SystemAlert.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def event_source(self):
        """Gets the event_source of this SystemAlert.  # noqa: E501


        :return: The event_source of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._event_source

    @event_source.setter
    def event_source(self, event_source):
        """Sets the event_source of this SystemAlert.


        :param event_source: The event_source of this SystemAlert.  # noqa: E501
        :type: str
        """
        allowed_values = ["SYSTEM", "DEVICE", "VIRTUALVOLUME", "EXTENT", "CLUSTER", "STORAGEVOLUME", "STORAGEARRAY", "LOGICALUNIT", "DIRECTOR", "SYSTEMVOLUME", "CONSISTENCYGROUP", "STORAGEVIEW", "LOGGINGVOLUME", "UNKNOWN"]  # noqa: E501
        if event_source not in allowed_values:
            raise ValueError(
                "Invalid value for `event_source` ({0}), must be one of {1}"  # noqa: E501
                .format(event_source, allowed_values)
            )

        self._event_source = event_source

    @property
    def event_source_id(self):
        """Gets the event_source_id of this SystemAlert.  # noqa: E501


        :return: The event_source_id of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._event_source_id

    @event_source_id.setter
    def event_source_id(self, event_source_id):
        """Sets the event_source_id of this SystemAlert.


        :param event_source_id: The event_source_id of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._event_source_id = event_source_id

    @property
    def external_rca(self):
        """Gets the external_rca of this SystemAlert.  # noqa: E501


        :return: The external_rca of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._external_rca

    @external_rca.setter
    def external_rca(self, external_rca):
        """Sets the external_rca of this SystemAlert.


        :param external_rca: The external_rca of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._external_rca = external_rca

    @property
    def id(self):
        """Gets the id of this SystemAlert.  # noqa: E501

        The unique ID of the system alert  # noqa: E501

        :return: The id of this SystemAlert.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemAlert.

        The unique ID of the system alert  # noqa: E501

        :param id: The id of this SystemAlert.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def last_modified(self):
        """Gets the last_modified of this SystemAlert.  # noqa: E501


        :return: The last_modified of this SystemAlert.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this SystemAlert.


        :param last_modified: The last_modified of this SystemAlert.  # noqa: E501
        :type: datetime
        """

        self._last_modified = last_modified

    @property
    def message(self):
        """Gets the message of this SystemAlert.  # noqa: E501


        :return: The message of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this SystemAlert.


        :param message: The message of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def name(self):
        """Gets the name of this SystemAlert.  # noqa: E501


        :return: The name of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SystemAlert.


        :param name: The name of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resource(self):
        """Gets the resource of this SystemAlert.  # noqa: E501

        Resource that generated the alert  # noqa: E501

        :return: The resource of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this SystemAlert.

        Resource that generated the alert  # noqa: E501

        :param resource: The resource of this SystemAlert.  # noqa: E501
        :type: str
        """

        self._resource = resource

    @property
    def scope(self):
        """Gets the scope of this SystemAlert.  # noqa: E501


        :return: The scope of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this SystemAlert.


        :param scope: The scope of this SystemAlert.  # noqa: E501
        :type: str
        """
        allowed_values = ["CLUSTER", "DIRECTOR", "MANAGEMENTSERVER", "UNKNOWN"]  # noqa: E501
        if scope not in allowed_values:
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def severity(self):
        """Gets the severity of this SystemAlert.  # noqa: E501


        :return: The severity of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this SystemAlert.


        :param severity: The severity of this SystemAlert.  # noqa: E501
        :type: str
        """
        allowed_values = ["CRITICAL", "ERROR", "WARNING", "INFO", "CLEAR", "UNKNOWN"]  # noqa: E501
        if severity not in allowed_values:
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}"  # noqa: E501
                .format(severity, allowed_values)
            )

        self._severity = severity

    @property
    def state(self):
        """Gets the state of this SystemAlert.  # noqa: E501


        :return: The state of this SystemAlert.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SystemAlert.


        :param state: The state of this SystemAlert.  # noqa: E501
        :type: str
        """
        allowed_values = ["OPEN", "CLOSE", "ACK", "UNKNOWN"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemAlert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Engine(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_ip_seed': 'str',
        'enclosure_id': 'str',
        'engine_id': 'str',
        'engine_family': 'str',
        'health_indications': 'list[str]',
        'health_state': 'str',
        'marker_led': 'str',
        'operational_status': 'str',
        'part_number': 'str',
        'revision_number': 'str',
        'serial_number': 'str',
        'top_level_assembly': 'str',
        'wwn_seed': 'str',
        'name': 'str'
    }

    attribute_map = {
        'cluster_ip_seed': 'cluster_ip_seed',
        'enclosure_id': 'enclosure_id',
        'engine_id': 'engine_id',
        'engine_family': 'engine_family',
        'health_indications': 'health_indications',
        'health_state': 'health_state',
        'marker_led': 'marker_led',
        'operational_status': 'operational_status',
        'part_number': 'part_number',
        'revision_number': 'revision_number',
        'serial_number': 'serial_number',
        'top_level_assembly': 'top_level_assembly',
        'wwn_seed': 'wwn_seed',
        'name': 'name'
    }

    def __init__(self, cluster_ip_seed=None, enclosure_id=None, engine_id=None, engine_family=None, health_indications=None, health_state=None, marker_led=None, operational_status=None, part_number=None, revision_number=None, serial_number=None, top_level_assembly=None, wwn_seed=None, name=None):  # noqa: E501
        """Engine - a model defined in Swagger"""  # noqa: E501

        self._cluster_ip_seed = None
        self._enclosure_id = None
        self._engine_id = None
        self._engine_family = None
        self._health_indications = None
        self._health_state = None
        self._marker_led = None
        self._operational_status = None
        self._part_number = None
        self._revision_number = None
        self._serial_number = None
        self._top_level_assembly = None
        self._wwn_seed = None
        self._name = None
        self.discriminator = None

        if cluster_ip_seed is not None:
            self.cluster_ip_seed = cluster_ip_seed
        if enclosure_id is not None:
            self.enclosure_id = enclosure_id
        if engine_id is not None:
            self.engine_id = engine_id
        if engine_family is not None:
            self.engine_family = engine_family
        if health_indications is not None:
            self.health_indications = health_indications
        if health_state is not None:
            self.health_state = health_state
        if marker_led is not None:
            self.marker_led = marker_led
        if operational_status is not None:
            self.operational_status = operational_status
        if part_number is not None:
            self.part_number = part_number
        if revision_number is not None:
            self.revision_number = revision_number
        if serial_number is not None:
            self.serial_number = serial_number
        if top_level_assembly is not None:
            self.top_level_assembly = top_level_assembly
        if wwn_seed is not None:
            self.wwn_seed = wwn_seed
        if name is not None:
            self.name = name

    @property
    def cluster_ip_seed(self):
        """Gets the cluster_ip_seed of this Engine.  # noqa: E501


        :return: The cluster_ip_seed of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._cluster_ip_seed

    @cluster_ip_seed.setter
    def cluster_ip_seed(self, cluster_ip_seed):
        """Sets the cluster_ip_seed of this Engine.


        :param cluster_ip_seed: The cluster_ip_seed of this Engine.  # noqa: E501
        :type: str
        """

        self._cluster_ip_seed = cluster_ip_seed

    @property
    def enclosure_id(self):
        """Gets the enclosure_id of this Engine.  # noqa: E501


        :return: The enclosure_id of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._enclosure_id

    @enclosure_id.setter
    def enclosure_id(self, enclosure_id):
        """Sets the enclosure_id of this Engine.


        :param enclosure_id: The enclosure_id of this Engine.  # noqa: E501
        :type: str
        """

        self._enclosure_id = enclosure_id

    @property
    def engine_id(self):
        """Gets the engine_id of this Engine.  # noqa: E501


        :return: The engine_id of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._engine_id

    @engine_id.setter
    def engine_id(self, engine_id):
        """Sets the engine_id of this Engine.


        :param engine_id: The engine_id of this Engine.  # noqa: E501
        :type: str
        """

        self._engine_id = engine_id

    @property
    def engine_family(self):
        """Gets the engine_family of this Engine.  # noqa: E501


        :return: The engine_family of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._engine_family

    @engine_family.setter
    def engine_family(self, engine_family):
        """Sets the engine_family of this Engine.


        :param engine_family: The engine_family of this Engine.  # noqa: E501
        :type: str
        """

        self._engine_family = engine_family

    @property
    def health_indications(self):
        """Gets the health_indications of this Engine.  # noqa: E501


        :return: The health_indications of this Engine.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this Engine.


        :param health_indications: The health_indications of this Engine.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def health_state(self):
        """Gets the health_state of this Engine.  # noqa: E501


        :return: The health_state of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this Engine.


        :param health_state: The health_state of this Engine.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def marker_led(self):
        """Gets the marker_led of this Engine.  # noqa: E501


        :return: The marker_led of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._marker_led

    @marker_led.setter
    def marker_led(self, marker_led):
        """Sets the marker_led of this Engine.


        :param marker_led: The marker_led of this Engine.  # noqa: E501
        :type: str
        """

        self._marker_led = marker_led

    @property
    def operational_status(self):
        """Gets the operational_status of this Engine.  # noqa: E501


        :return: The operational_status of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this Engine.


        :param operational_status: The operational_status of this Engine.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def part_number(self):
        """Gets the part_number of this Engine.  # noqa: E501


        :return: The part_number of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this Engine.


        :param part_number: The part_number of this Engine.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def revision_number(self):
        """Gets the revision_number of this Engine.  # noqa: E501


        :return: The revision_number of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._revision_number

    @revision_number.setter
    def revision_number(self, revision_number):
        """Sets the revision_number of this Engine.


        :param revision_number: The revision_number of this Engine.  # noqa: E501
        :type: str
        """

        self._revision_number = revision_number

    @property
    def serial_number(self):
        """Gets the serial_number of this Engine.  # noqa: E501


        :return: The serial_number of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this Engine.


        :param serial_number: The serial_number of this Engine.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def top_level_assembly(self):
        """Gets the top_level_assembly of this Engine.  # noqa: E501


        :return: The top_level_assembly of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._top_level_assembly

    @top_level_assembly.setter
    def top_level_assembly(self, top_level_assembly):
        """Sets the top_level_assembly of this Engine.


        :param top_level_assembly: The top_level_assembly of this Engine.  # noqa: E501
        :type: str
        """

        self._top_level_assembly = top_level_assembly

    @property
    def wwn_seed(self):
        """Gets the wwn_seed of this Engine.  # noqa: E501


        :return: The wwn_seed of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._wwn_seed

    @wwn_seed.setter
    def wwn_seed(self, wwn_seed):
        """Sets the wwn_seed of this Engine.


        :param wwn_seed: The wwn_seed of this Engine.  # noqa: E501
        :type: str
        """

        self._wwn_seed = wwn_seed

    @property
    def name(self):
        """Gets the name of this Engine.  # noqa: E501


        :return: The name of this Engine.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Engine.


        :param name: The name of this Engine.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Engine):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoragePool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'total_free_space': 'float',
        'total_used_space': 'float',
        'total_space': 'float',
        'pool_types': 'str',
        'policies': 'str',
        'last_refreshed': 'str'
    }

    attribute_map = {
        'name': 'name',
        'total_free_space': 'total_free_space',
        'total_used_space': 'total_used_space',
        'total_space': 'total_space',
        'pool_types': 'pool_types',
        'policies': 'policies',
        'last_refreshed': 'last_refreshed'
    }

    def __init__(self, name=None, total_free_space=None, total_used_space=None, total_space=None, pool_types=None, policies=None, last_refreshed=None):  # noqa: E501
        """StoragePool - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._total_free_space = None
        self._total_used_space = None
        self._total_space = None
        self._pool_types = None
        self._policies = None
        self._last_refreshed = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if total_free_space is not None:
            self.total_free_space = total_free_space
        if total_used_space is not None:
            self.total_used_space = total_used_space
        if total_space is not None:
            self.total_space = total_space
        if pool_types is not None:
            self.pool_types = pool_types
        if policies is not None:
            self.policies = policies
        if last_refreshed is not None:
            self.last_refreshed = last_refreshed

    @property
    def name(self):
        """Gets the name of this StoragePool.  # noqa: E501


        :return: The name of this StoragePool.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StoragePool.


        :param name: The name of this StoragePool.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def total_free_space(self):
        """Gets the total_free_space of this StoragePool.  # noqa: E501


        :return: The total_free_space of this StoragePool.  # noqa: E501
        :rtype: float
        """
        return self._total_free_space

    @total_free_space.setter
    def total_free_space(self, total_free_space):
        """Sets the total_free_space of this StoragePool.


        :param total_free_space: The total_free_space of this StoragePool.  # noqa: E501
        :type: float
        """

        self._total_free_space = total_free_space

    @property
    def total_used_space(self):
        """Gets the total_used_space of this StoragePool.  # noqa: E501


        :return: The total_used_space of this StoragePool.  # noqa: E501
        :rtype: float
        """
        return self._total_used_space

    @total_used_space.setter
    def total_used_space(self, total_used_space):
        """Sets the total_used_space of this StoragePool.


        :param total_used_space: The total_used_space of this StoragePool.  # noqa: E501
        :type: float
        """

        self._total_used_space = total_used_space

    @property
    def total_space(self):
        """Gets the total_space of this StoragePool.  # noqa: E501


        :return: The total_space of this StoragePool.  # noqa: E501
        :rtype: float
        """
        return self._total_space

    @total_space.setter
    def total_space(self, total_space):
        """Sets the total_space of this StoragePool.


        :param total_space: The total_space of this StoragePool.  # noqa: E501
        :type: float
        """

        self._total_space = total_space

    @property
    def pool_types(self):
        """Gets the pool_types of this StoragePool.  # noqa: E501


        :return: The pool_types of this StoragePool.  # noqa: E501
        :rtype: str
        """
        return self._pool_types

    @pool_types.setter
    def pool_types(self, pool_types):
        """Sets the pool_types of this StoragePool.


        :param pool_types: The pool_types of this StoragePool.  # noqa: E501
        :type: str
        """

        self._pool_types = pool_types

    @property
    def policies(self):
        """Gets the policies of this StoragePool.  # noqa: E501


        :return: The policies of this StoragePool.  # noqa: E501
        :rtype: str
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this StoragePool.


        :param policies: The policies of this StoragePool.  # noqa: E501
        :type: str
        """

        self._policies = policies

    @property
    def last_refreshed(self):
        """Gets the last_refreshed of this StoragePool.  # noqa: E501


        :return: The last_refreshed of this StoragePool.  # noqa: E501
        :rtype: str
        """
        return self._last_refreshed

    @last_refreshed.setter
    def last_refreshed(self, last_refreshed):
        """Sets the last_refreshed of this StoragePool.


        :param last_refreshed: The last_refreshed of this StoragePool.  # noqa: E501
        :type: str
        """

        self._last_refreshed = last_refreshed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoragePool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Device(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'block_count': 'float',
        'block_size': 'float',
        'capacity': 'float',
        'transfer_size': 'float',
        'health_indications': 'list[str]',
        'health_state': 'str',
        'operational_status': 'str',
        'virtual_volume': 'str',
        'visibility': 'str',
        'locality': 'str',
        'geometry': 'str',
        'application_consistent': 'bool',
        'auto_resume': 'bool',
        'rebuild_eta': 'str',
        'rebuild_allowed': 'bool',
        'rebuild_progress': 'str',
        'rebuild_status': 'str',
        'rebuild_type': 'str',
        'service_status': 'str',
        'storage_array_family': 'str',
        'stripe_depth': 'str',
        'system_id': 'str',
        'thin_capable': 'bool',
        'top_level': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'block_count': 'block_count',
        'block_size': 'block_size',
        'capacity': 'capacity',
        'transfer_size': 'transfer_size',
        'health_indications': 'health_indications',
        'health_state': 'health_state',
        'operational_status': 'operational_status',
        'virtual_volume': 'virtual_volume',
        'visibility': 'visibility',
        'locality': 'locality',
        'geometry': 'geometry',
        'application_consistent': 'application_consistent',
        'auto_resume': 'auto_resume',
        'rebuild_eta': 'rebuild_eta',
        'rebuild_allowed': 'rebuild_allowed',
        'rebuild_progress': 'rebuild_progress',
        'rebuild_status': 'rebuild_status',
        'rebuild_type': 'rebuild_type',
        'service_status': 'service_status',
        'storage_array_family': 'storage_array_family',
        'stripe_depth': 'stripe_depth',
        'system_id': 'system_id',
        'thin_capable': 'thin_capable',
        'top_level': 'top_level'
    }

    def __init__(self, name=None, block_count=None, block_size=None, capacity=None, transfer_size=None, health_indications=None, health_state=None, operational_status=None, virtual_volume=None, visibility=None, locality=None, geometry=None, application_consistent=None, auto_resume=None, rebuild_eta=None, rebuild_allowed=None, rebuild_progress=None, rebuild_status=None, rebuild_type=None, service_status=None, storage_array_family=None, stripe_depth=None, system_id=None, thin_capable=None, top_level=None):  # noqa: E501
        """Device - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._block_count = None
        self._block_size = None
        self._capacity = None
        self._transfer_size = None
        self._health_indications = None
        self._health_state = None
        self._operational_status = None
        self._virtual_volume = None
        self._visibility = None
        self._locality = None
        self._geometry = None
        self._application_consistent = None
        self._auto_resume = None
        self._rebuild_eta = None
        self._rebuild_allowed = None
        self._rebuild_progress = None
        self._rebuild_status = None
        self._rebuild_type = None
        self._service_status = None
        self._storage_array_family = None
        self._stripe_depth = None
        self._system_id = None
        self._thin_capable = None
        self._top_level = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if block_count is not None:
            self.block_count = block_count
        if block_size is not None:
            self.block_size = block_size
        if capacity is not None:
            self.capacity = capacity
        if transfer_size is not None:
            self.transfer_size = transfer_size
        if health_indications is not None:
            self.health_indications = health_indications
        if health_state is not None:
            self.health_state = health_state
        if operational_status is not None:
            self.operational_status = operational_status
        if virtual_volume is not None:
            self.virtual_volume = virtual_volume
        if visibility is not None:
            self.visibility = visibility
        if locality is not None:
            self.locality = locality
        if geometry is not None:
            self.geometry = geometry
        if application_consistent is not None:
            self.application_consistent = application_consistent
        if auto_resume is not None:
            self.auto_resume = auto_resume
        if rebuild_eta is not None:
            self.rebuild_eta = rebuild_eta
        if rebuild_allowed is not None:
            self.rebuild_allowed = rebuild_allowed
        if rebuild_progress is not None:
            self.rebuild_progress = rebuild_progress
        if rebuild_status is not None:
            self.rebuild_status = rebuild_status
        if rebuild_type is not None:
            self.rebuild_type = rebuild_type
        if service_status is not None:
            self.service_status = service_status
        if storage_array_family is not None:
            self.storage_array_family = storage_array_family
        if stripe_depth is not None:
            self.stripe_depth = stripe_depth
        if system_id is not None:
            self.system_id = system_id
        if thin_capable is not None:
            self.thin_capable = thin_capable
        if top_level is not None:
            self.top_level = top_level

    @property
    def name(self):
        """Gets the name of this Device.  # noqa: E501


        :return: The name of this Device.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Device.


        :param name: The name of this Device.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def block_count(self):
        """Gets the block_count of this Device.  # noqa: E501


        :return: The block_count of this Device.  # noqa: E501
        :rtype: float
        """
        return self._block_count

    @block_count.setter
    def block_count(self, block_count):
        """Sets the block_count of this Device.


        :param block_count: The block_count of this Device.  # noqa: E501
        :type: float
        """

        self._block_count = block_count

    @property
    def block_size(self):
        """Gets the block_size of this Device.  # noqa: E501


        :return: The block_size of this Device.  # noqa: E501
        :rtype: float
        """
        return self._block_size

    @block_size.setter
    def block_size(self, block_size):
        """Sets the block_size of this Device.


        :param block_size: The block_size of this Device.  # noqa: E501
        :type: float
        """

        self._block_size = block_size

    @property
    def capacity(self):
        """Gets the capacity of this Device.  # noqa: E501


        :return: The capacity of this Device.  # noqa: E501
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this Device.


        :param capacity: The capacity of this Device.  # noqa: E501
        :type: float
        """

        self._capacity = capacity

    @property
    def transfer_size(self):
        """Gets the transfer_size of this Device.  # noqa: E501


        :return: The transfer_size of this Device.  # noqa: E501
        :rtype: float
        """
        return self._transfer_size

    @transfer_size.setter
    def transfer_size(self, transfer_size):
        """Sets the transfer_size of this Device.


        :param transfer_size: The transfer_size of this Device.  # noqa: E501
        :type: float
        """

        self._transfer_size = transfer_size

    @property
    def health_indications(self):
        """Gets the health_indications of this Device.  # noqa: E501


        :return: The health_indications of this Device.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this Device.


        :param health_indications: The health_indications of this Device.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def health_state(self):
        """Gets the health_state of this Device.  # noqa: E501


        :return: The health_state of this Device.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this Device.


        :param health_state: The health_state of this Device.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def operational_status(self):
        """Gets the operational_status of this Device.  # noqa: E501


        :return: The operational_status of this Device.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this Device.


        :param operational_status: The operational_status of this Device.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def virtual_volume(self):
        """Gets the virtual_volume of this Device.  # noqa: E501


        :return: The virtual_volume of this Device.  # noqa: E501
        :rtype: str
        """
        return self._virtual_volume

    @virtual_volume.setter
    def virtual_volume(self, virtual_volume):
        """Sets the virtual_volume of this Device.


        :param virtual_volume: The virtual_volume of this Device.  # noqa: E501
        :type: str
        """

        self._virtual_volume = virtual_volume

    @property
    def visibility(self):
        """Gets the visibility of this Device.  # noqa: E501


        :return: The visibility of this Device.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this Device.


        :param visibility: The visibility of this Device.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def locality(self):
        """Gets the locality of this Device.  # noqa: E501


        :return: The locality of this Device.  # noqa: E501
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this Device.


        :param locality: The locality of this Device.  # noqa: E501
        :type: str
        """

        self._locality = locality

    @property
    def geometry(self):
        """Gets the geometry of this Device.  # noqa: E501


        :return: The geometry of this Device.  # noqa: E501
        :rtype: str
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this Device.


        :param geometry: The geometry of this Device.  # noqa: E501
        :type: str
        """

        self._geometry = geometry

    @property
    def application_consistent(self):
        """Gets the application_consistent of this Device.  # noqa: E501


        :return: The application_consistent of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._application_consistent

    @application_consistent.setter
    def application_consistent(self, application_consistent):
        """Sets the application_consistent of this Device.


        :param application_consistent: The application_consistent of this Device.  # noqa: E501
        :type: bool
        """

        self._application_consistent = application_consistent

    @property
    def auto_resume(self):
        """Gets the auto_resume of this Device.  # noqa: E501


        :return: The auto_resume of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._auto_resume

    @auto_resume.setter
    def auto_resume(self, auto_resume):
        """Sets the auto_resume of this Device.


        :param auto_resume: The auto_resume of this Device.  # noqa: E501
        :type: bool
        """

        self._auto_resume = auto_resume

    @property
    def rebuild_eta(self):
        """Gets the rebuild_eta of this Device.  # noqa: E501


        :return: The rebuild_eta of this Device.  # noqa: E501
        :rtype: str
        """
        return self._rebuild_eta

    @rebuild_eta.setter
    def rebuild_eta(self, rebuild_eta):
        """Sets the rebuild_eta of this Device.


        :param rebuild_eta: The rebuild_eta of this Device.  # noqa: E501
        :type: str
        """

        self._rebuild_eta = rebuild_eta

    @property
    def rebuild_allowed(self):
        """Gets the rebuild_allowed of this Device.  # noqa: E501


        :return: The rebuild_allowed of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._rebuild_allowed

    @rebuild_allowed.setter
    def rebuild_allowed(self, rebuild_allowed):
        """Sets the rebuild_allowed of this Device.


        :param rebuild_allowed: The rebuild_allowed of this Device.  # noqa: E501
        :type: bool
        """

        self._rebuild_allowed = rebuild_allowed

    @property
    def rebuild_progress(self):
        """Gets the rebuild_progress of this Device.  # noqa: E501


        :return: The rebuild_progress of this Device.  # noqa: E501
        :rtype: str
        """
        return self._rebuild_progress

    @rebuild_progress.setter
    def rebuild_progress(self, rebuild_progress):
        """Sets the rebuild_progress of this Device.


        :param rebuild_progress: The rebuild_progress of this Device.  # noqa: E501
        :type: str
        """

        self._rebuild_progress = rebuild_progress

    @property
    def rebuild_status(self):
        """Gets the rebuild_status of this Device.  # noqa: E501


        :return: The rebuild_status of this Device.  # noqa: E501
        :rtype: str
        """
        return self._rebuild_status

    @rebuild_status.setter
    def rebuild_status(self, rebuild_status):
        """Sets the rebuild_status of this Device.


        :param rebuild_status: The rebuild_status of this Device.  # noqa: E501
        :type: str
        """

        self._rebuild_status = rebuild_status

    @property
    def rebuild_type(self):
        """Gets the rebuild_type of this Device.  # noqa: E501


        :return: The rebuild_type of this Device.  # noqa: E501
        :rtype: str
        """
        return self._rebuild_type

    @rebuild_type.setter
    def rebuild_type(self, rebuild_type):
        """Sets the rebuild_type of this Device.


        :param rebuild_type: The rebuild_type of this Device.  # noqa: E501
        :type: str
        """

        self._rebuild_type = rebuild_type

    @property
    def service_status(self):
        """Gets the service_status of this Device.  # noqa: E501


        :return: The service_status of this Device.  # noqa: E501
        :rtype: str
        """
        return self._service_status

    @service_status.setter
    def service_status(self, service_status):
        """Sets the service_status of this Device.


        :param service_status: The service_status of this Device.  # noqa: E501
        :type: str
        """

        self._service_status = service_status

    @property
    def storage_array_family(self):
        """Gets the storage_array_family of this Device.  # noqa: E501


        :return: The storage_array_family of this Device.  # noqa: E501
        :rtype: str
        """
        return self._storage_array_family

    @storage_array_family.setter
    def storage_array_family(self, storage_array_family):
        """Sets the storage_array_family of this Device.


        :param storage_array_family: The storage_array_family of this Device.  # noqa: E501
        :type: str
        """

        self._storage_array_family = storage_array_family

    @property
    def stripe_depth(self):
        """Gets the stripe_depth of this Device.  # noqa: E501


        :return: The stripe_depth of this Device.  # noqa: E501
        :rtype: str
        """
        return self._stripe_depth

    @stripe_depth.setter
    def stripe_depth(self, stripe_depth):
        """Sets the stripe_depth of this Device.


        :param stripe_depth: The stripe_depth of this Device.  # noqa: E501
        :type: str
        """

        self._stripe_depth = stripe_depth

    @property
    def system_id(self):
        """Gets the system_id of this Device.  # noqa: E501


        :return: The system_id of this Device.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this Device.


        :param system_id: The system_id of this Device.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def thin_capable(self):
        """Gets the thin_capable of this Device.  # noqa: E501


        :return: The thin_capable of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._thin_capable

    @thin_capable.setter
    def thin_capable(self, thin_capable):
        """Sets the thin_capable of this Device.


        :param thin_capable: The thin_capable of this Device.  # noqa: E501
        :type: bool
        """

        self._thin_capable = thin_capable

    @property
    def top_level(self):
        """Gets the top_level of this Device.  # noqa: E501


        :return: The top_level of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._top_level

    @top_level.setter
    def top_level(self, top_level):
        """Sets the top_level of this Device.


        :param top_level: The top_level of this Device.  # noqa: E501
        :type: bool
        """

        self._top_level = top_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Device):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StorageGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'masking_views': 'list[str]',
        'number_of_volumes': 'str',
        'parent_storage_group': 'str',
        'policy': 'str',
        'srp': 'str'
    }

    attribute_map = {
        'name': 'name',
        'masking_views': 'masking_views',
        'number_of_volumes': 'number_of_volumes',
        'parent_storage_group': 'parent_storage_group',
        'policy': 'policy',
        'srp': 'SRP'
    }

    def __init__(self, name=None, masking_views=None, number_of_volumes=None, parent_storage_group=None, policy=None, srp=None):  # noqa: E501
        """StorageGroup - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._masking_views = None
        self._number_of_volumes = None
        self._parent_storage_group = None
        self._policy = None
        self._srp = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if masking_views is not None:
            self.masking_views = masking_views
        if number_of_volumes is not None:
            self.number_of_volumes = number_of_volumes
        if parent_storage_group is not None:
            self.parent_storage_group = parent_storage_group
        if policy is not None:
            self.policy = policy
        if srp is not None:
            self.srp = srp

    @property
    def name(self):
        """Gets the name of this StorageGroup.  # noqa: E501


        :return: The name of this StorageGroup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageGroup.


        :param name: The name of this StorageGroup.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def masking_views(self):
        """Gets the masking_views of this StorageGroup.  # noqa: E501


        :return: The masking_views of this StorageGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._masking_views

    @masking_views.setter
    def masking_views(self, masking_views):
        """Sets the masking_views of this StorageGroup.


        :param masking_views: The masking_views of this StorageGroup.  # noqa: E501
        :type: list[str]
        """

        self._masking_views = masking_views

    @property
    def number_of_volumes(self):
        """Gets the number_of_volumes of this StorageGroup.  # noqa: E501


        :return: The number_of_volumes of this StorageGroup.  # noqa: E501
        :rtype: str
        """
        return self._number_of_volumes

    @number_of_volumes.setter
    def number_of_volumes(self, number_of_volumes):
        """Sets the number_of_volumes of this StorageGroup.


        :param number_of_volumes: The number_of_volumes of this StorageGroup.  # noqa: E501
        :type: str
        """

        self._number_of_volumes = number_of_volumes

    @property
    def parent_storage_group(self):
        """Gets the parent_storage_group of this StorageGroup.  # noqa: E501


        :return: The parent_storage_group of this StorageGroup.  # noqa: E501
        :rtype: str
        """
        return self._parent_storage_group

    @parent_storage_group.setter
    def parent_storage_group(self, parent_storage_group):
        """Sets the parent_storage_group of this StorageGroup.


        :param parent_storage_group: The parent_storage_group of this StorageGroup.  # noqa: E501
        :type: str
        """

        self._parent_storage_group = parent_storage_group

    @property
    def policy(self):
        """Gets the policy of this StorageGroup.  # noqa: E501


        :return: The policy of this StorageGroup.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this StorageGroup.


        :param policy: The policy of this StorageGroup.  # noqa: E501
        :type: str
        """

        self._policy = policy

    @property
    def srp(self):
        """Gets the srp of this StorageGroup.  # noqa: E501


        :return: The srp of this StorageGroup.  # noqa: E501
        :rtype: str
        """
        return self._srp

    @srp.setter
    def srp(self, srp):
        """Sets the srp of this StorageGroup.


        :param srp: The srp of this StorageGroup.  # noqa: E501
        :type: str
        """

        self._srp = srp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vplexapi.api_client import ApiClient


class MetadataBackupApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_backup_metadata(self, cluster_name, metadata_backup_payload, **kwargs):  # noqa: E501
        """Create List of configured MetaData Backups Volume with their scheduled time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_backup_metadata(cluster_name, metadata_backup_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :param MetadataBackupPayload metadata_backup_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: InlineResponse201
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_backup_metadata_with_http_info(cluster_name, metadata_backup_payload, **kwargs)  # noqa: E501
        else:
            (data) = self.create_backup_metadata_with_http_info(cluster_name, metadata_backup_payload, **kwargs)  # noqa: E501
            return data

    def create_backup_metadata_with_http_info(self, cluster_name, metadata_backup_payload, **kwargs):  # noqa: E501
        """Create List of configured MetaData Backups Volume with their scheduled time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_backup_metadata_with_http_info(cluster_name, metadata_backup_payload, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :param MetadataBackupPayload metadata_backup_payload: (required)
        :param str x_include_object: When passed as part of a POST request, controls whether the representation of the newly created object is included in the response. Defaults to 'true' which will include the object in the response. This header is useful because refreshing the newly created object is usually the slowest part of a POST operation. 
        :return: InlineResponse201
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_name', 'metadata_backup_payload', 'x_include_object']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_backup_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_name' is set
        if ('cluster_name' not in params or
                params['cluster_name'] is None):
            raise ValueError("Missing the required parameter `cluster_name` when calling `create_backup_metadata`")  # noqa: E501
        # verify the required parameter 'metadata_backup_payload' is set
        if ('metadata_backup_payload' not in params or
                params['metadata_backup_payload'] is None):
            raise ValueError("Missing the required parameter `metadata_backup_payload` when calling `create_backup_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_name' in params:
            path_params['cluster_name'] = params['cluster_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_include_object' in params:
            header_params['X-Include-Object'] = params['x_include_object']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'metadata_backup_payload' in params:
            body_params = params['metadata_backup_payload']
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_name}/metadata_backups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse201',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_backup_metadata(self, cluster_name, **kwargs):  # noqa: E501
        """Delete configured Metadata backup settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_backup_metadata(cluster_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_backup_metadata_with_http_info(cluster_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_backup_metadata_with_http_info(cluster_name, **kwargs)  # noqa: E501
            return data

    def delete_backup_metadata_with_http_info(self, cluster_name, **kwargs):  # noqa: E501
        """Delete configured Metadata backup settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_backup_metadata_with_http_info(cluster_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_backup_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_name' is set
        if ('cluster_name' not in params or
                params['cluster_name'] is None):
            raise ValueError("Missing the required parameter `cluster_name` when calling `delete_backup_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_name' in params:
            path_params['cluster_name'] = params['cluster_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_name}/metadata_backups', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_backup_metadata(self, cluster_name, **kwargs):  # noqa: E501
        """List the configured MetaData Backup settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_backup_metadata(cluster_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_backup_metadata_with_http_info(cluster_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_backup_metadata_with_http_info(cluster_name, **kwargs)  # noqa: E501
            return data

    def get_backup_metadata_with_http_info(self, cluster_name, **kwargs):  # noqa: E501
        """List the configured MetaData Backup settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_backup_metadata_with_http_info(cluster_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str cluster_name: The name of the cluster (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cluster_name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_backup_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cluster_name' is set
        if ('cluster_name' not in params or
                params['cluster_name'] is None):
            raise ValueError("Missing the required parameter `cluster_name` when calling `get_backup_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cluster_name' in params:
            path_params['cluster_name'] = params['cluster_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/clusters/{cluster_name}/metadata_backups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.connectivity_status import ConnectivityStatus  # noqa: F401,E501


class LogicalUnit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'active_aao_controller': 'list[str]',
        'passive_aan_controller': 'list[str]',
        'active_aao_visibility': 'list[str]',
        'passive_aan_visibility': 'list[str]',
        'connectivity_status': 'ConnectivityStatus',
        'luns': 'list[str]',
        'storage_volume': 'str',
        'visibility': 'str',
        'alua_support': 'str'
    }

    attribute_map = {
        'name': 'name',
        'active_aao_controller': 'active_aao_controller',
        'passive_aan_controller': 'passive_aan_controller',
        'active_aao_visibility': 'active_aao_visibility',
        'passive_aan_visibility': 'passive_aan_visibility',
        'connectivity_status': 'connectivity_status',
        'luns': 'luns',
        'storage_volume': 'storage_volume',
        'visibility': 'visibility',
        'alua_support': 'alua_support'
    }

    def __init__(self, name=None, active_aao_controller=None, passive_aan_controller=None, active_aao_visibility=None, passive_aan_visibility=None, connectivity_status=None, luns=None, storage_volume=None, visibility=None, alua_support=None):  # noqa: E501
        """LogicalUnit - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._active_aao_controller = None
        self._passive_aan_controller = None
        self._active_aao_visibility = None
        self._passive_aan_visibility = None
        self._connectivity_status = None
        self._luns = None
        self._storage_volume = None
        self._visibility = None
        self._alua_support = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if active_aao_controller is not None:
            self.active_aao_controller = active_aao_controller
        if passive_aan_controller is not None:
            self.passive_aan_controller = passive_aan_controller
        if active_aao_visibility is not None:
            self.active_aao_visibility = active_aao_visibility
        if passive_aan_visibility is not None:
            self.passive_aan_visibility = passive_aan_visibility
        if connectivity_status is not None:
            self.connectivity_status = connectivity_status
        if luns is not None:
            self.luns = luns
        if storage_volume is not None:
            self.storage_volume = storage_volume
        if visibility is not None:
            self.visibility = visibility
        if alua_support is not None:
            self.alua_support = alua_support

    @property
    def name(self):
        """Gets the name of this LogicalUnit.  # noqa: E501


        :return: The name of this LogicalUnit.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LogicalUnit.


        :param name: The name of this LogicalUnit.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def active_aao_controller(self):
        """Gets the active_aao_controller of this LogicalUnit.  # noqa: E501


        :return: The active_aao_controller of this LogicalUnit.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_aao_controller

    @active_aao_controller.setter
    def active_aao_controller(self, active_aao_controller):
        """Sets the active_aao_controller of this LogicalUnit.


        :param active_aao_controller: The active_aao_controller of this LogicalUnit.  # noqa: E501
        :type: list[str]
        """

        self._active_aao_controller = active_aao_controller

    @property
    def passive_aan_controller(self):
        """Gets the passive_aan_controller of this LogicalUnit.  # noqa: E501


        :return: The passive_aan_controller of this LogicalUnit.  # noqa: E501
        :rtype: list[str]
        """
        return self._passive_aan_controller

    @passive_aan_controller.setter
    def passive_aan_controller(self, passive_aan_controller):
        """Sets the passive_aan_controller of this LogicalUnit.


        :param passive_aan_controller: The passive_aan_controller of this LogicalUnit.  # noqa: E501
        :type: list[str]
        """

        self._passive_aan_controller = passive_aan_controller

    @property
    def active_aao_visibility(self):
        """Gets the active_aao_visibility of this LogicalUnit.  # noqa: E501


        :return: The active_aao_visibility of this LogicalUnit.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_aao_visibility

    @active_aao_visibility.setter
    def active_aao_visibility(self, active_aao_visibility):
        """Sets the active_aao_visibility of this LogicalUnit.


        :param active_aao_visibility: The active_aao_visibility of this LogicalUnit.  # noqa: E501
        :type: list[str]
        """

        self._active_aao_visibility = active_aao_visibility

    @property
    def passive_aan_visibility(self):
        """Gets the passive_aan_visibility of this LogicalUnit.  # noqa: E501


        :return: The passive_aan_visibility of this LogicalUnit.  # noqa: E501
        :rtype: list[str]
        """
        return self._passive_aan_visibility

    @passive_aan_visibility.setter
    def passive_aan_visibility(self, passive_aan_visibility):
        """Sets the passive_aan_visibility of this LogicalUnit.


        :param passive_aan_visibility: The passive_aan_visibility of this LogicalUnit.  # noqa: E501
        :type: list[str]
        """

        self._passive_aan_visibility = passive_aan_visibility

    @property
    def connectivity_status(self):
        """Gets the connectivity_status of this LogicalUnit.  # noqa: E501


        :return: The connectivity_status of this LogicalUnit.  # noqa: E501
        :rtype: ConnectivityStatus
        """
        return self._connectivity_status

    @connectivity_status.setter
    def connectivity_status(self, connectivity_status):
        """Sets the connectivity_status of this LogicalUnit.


        :param connectivity_status: The connectivity_status of this LogicalUnit.  # noqa: E501
        :type: ConnectivityStatus
        """

        self._connectivity_status = connectivity_status

    @property
    def luns(self):
        """Gets the luns of this LogicalUnit.  # noqa: E501


        :return: The luns of this LogicalUnit.  # noqa: E501
        :rtype: list[str]
        """
        return self._luns

    @luns.setter
    def luns(self, luns):
        """Sets the luns of this LogicalUnit.


        :param luns: The luns of this LogicalUnit.  # noqa: E501
        :type: list[str]
        """

        self._luns = luns

    @property
    def storage_volume(self):
        """Gets the storage_volume of this LogicalUnit.  # noqa: E501


        :return: The storage_volume of this LogicalUnit.  # noqa: E501
        :rtype: str
        """
        return self._storage_volume

    @storage_volume.setter
    def storage_volume(self, storage_volume):
        """Sets the storage_volume of this LogicalUnit.


        :param storage_volume: The storage_volume of this LogicalUnit.  # noqa: E501
        :type: str
        """

        self._storage_volume = storage_volume

    @property
    def visibility(self):
        """Gets the visibility of this LogicalUnit.  # noqa: E501


        :return: The visibility of this LogicalUnit.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this LogicalUnit.


        :param visibility: The visibility of this LogicalUnit.  # noqa: E501
        :type: str
        """
        allowed_values = ["active", "passsive", "active-optimized", "active-non-optimized", "both", "both-alua", "none"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    @property
    def alua_support(self):
        """Gets the alua_support of this LogicalUnit.  # noqa: E501


        :return: The alua_support of this LogicalUnit.  # noqa: E501
        :rtype: str
        """
        return self._alua_support

    @alua_support.setter
    def alua_support(self, alua_support):
        """Sets the alua_support of this LogicalUnit.


        :param alua_support: The alua_support of this LogicalUnit.  # noqa: E501
        :type: str
        """
        allowed_values = ["implicit", "explicit", "none", "implicit-explicit"]  # noqa: E501
        if alua_support not in allowed_values:
            raise ValueError(
                "Invalid value for `alua_support` ({0}), must be one of {1}"  # noqa: E501
                .format(alua_support, allowed_values)
            )

        self._alua_support = alua_support

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogicalUnit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SystemConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'platform': 'str',
        'product_type': 'str',
        'wan_type': 'str',
        'limits': 'object'
    }

    attribute_map = {
        'platform': 'platform',
        'product_type': 'product_type',
        'wan_type': 'wan_type',
        'limits': 'limits'
    }

    def __init__(self, platform=None, product_type=None, wan_type=None, limits=None):  # noqa: E501
        """SystemConfig - a model defined in Swagger"""  # noqa: E501

        self._platform = None
        self._product_type = None
        self._wan_type = None
        self._limits = None
        self.discriminator = None

        if platform is not None:
            self.platform = platform
        if product_type is not None:
            self.product_type = product_type
        if wan_type is not None:
            self.wan_type = wan_type
        if limits is not None:
            self.limits = limits

    @property
    def platform(self):
        """Gets the platform of this SystemConfig.  # noqa: E501


        :return: The platform of this SystemConfig.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this SystemConfig.


        :param platform: The platform of this SystemConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["unknown", "VS2", "VS6"]  # noqa: E501
        if platform not in allowed_values:
            raise ValueError(
                "Invalid value for `platform` ({0}), must be one of {1}"  # noqa: E501
                .format(platform, allowed_values)
            )

        self._platform = platform

    @property
    def product_type(self):
        """Gets the product_type of this SystemConfig.  # noqa: E501


        :return: The product_type of this SystemConfig.  # noqa: E501
        :rtype: str
        """
        return self._product_type

    @product_type.setter
    def product_type(self, product_type):
        """Sets the product_type of this SystemConfig.


        :param product_type: The product_type of this SystemConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["local", "metro", "unknown"]  # noqa: E501
        if product_type not in allowed_values:
            raise ValueError(
                "Invalid value for `product_type` ({0}), must be one of {1}"  # noqa: E501
                .format(product_type, allowed_values)
            )

        self._product_type = product_type

    @property
    def wan_type(self):
        """Gets the wan_type of this SystemConfig.  # noqa: E501


        :return: The wan_type of this SystemConfig.  # noqa: E501
        :rtype: str
        """
        return self._wan_type

    @wan_type.setter
    def wan_type(self, wan_type):
        """Sets the wan_type of this SystemConfig.


        :param wan_type: The wan_type of this SystemConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["FC", "IP", "unknown"]  # noqa: E501
        if wan_type not in allowed_values:
            raise ValueError(
                "Invalid value for `wan_type` ({0}), must be one of {1}"  # noqa: E501
                .format(wan_type, allowed_values)
            )

        self._wan_type = wan_type

    @property
    def limits(self):
        """Gets the limits of this SystemConfig.  # noqa: E501


        :return: The limits of this SystemConfig.  # noqa: E501
        :rtype: object
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        """Sets the limits of this SystemConfig.


        :param limits: The limits of this SystemConfig.  # noqa: E501
        :type: object
        """

        self._limits = limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
